﻿///////////////////////////////////////////////////////////////////////////////////////////////////
// 
//  ACT距離計算サービス サンプルプログラム
//  CalcSettingsクラス
//
//  Copyrights (c) 2016-2023, Advanced Core Technologies, Inc. All rights reserved.
//
//  2023/09/21 Rev.1.0.0.1 KYON UseSsl変数をプロパティに変更
//  2016/01/15 Rev.1.0.0.0 MOTO 作成
//
///////////////////////////////////////////////////////////////////////////////////////////////////

using System;
using Act.Dcws;

namespace ACTSOAPCSCalcRoute
{
    /// <summary>
    /// 距離計算サービスに使用する設定を指定します。
    /// </summary>
    internal static class CalcSettings
    {
        //=========================================================================================
        //  Public Constants
        //=========================================================================================
        #region Public Constants

        /// <summary>
        /// 管理サービスURLの既定値です。
        /// </summary>
        public static readonly string DefaultAdminUrl = 
            @"https://distcalc.act-inc.co.jp/dcadmin/admin.asmx";

        /// <summary>
        /// 使用する計算用道路データ（000で始まる）のNWIDの正規表現です。
        /// </summary>
        public static readonly string NWIDPattern = "^(000)";

        /// <summary>
        /// 経緯度の測地系を指定します。日本測地系。
        /// </summary>
        public static readonly Datum Datum = Datum.Tokyo;

        /// <summary>
        /// 経緯度の座標フォーマット識別子を指定します。現在は常に0を指定します。
        /// </summary>
        public static readonly int CoordinateFormat = 0;

        /// <summary>
        /// 計算方法を指定します。時間最短。
        /// </summary>
        public static readonly CalcKind CalcKind = CalcKind.Time;

        /// <summary>
        /// 使用交通機関を指定します。
        /// 使用する交通機関が複数ある場合はその論理和を指定します。
        /// </summary>
        public static readonly Transport Transport = Transport.Highway;

        /// <summary>
        /// ポイント構造体に出力する走行ルートの種別を指定します。簡易ルート。
        /// </summary>
        public static readonly RouteKind RouteKind = RouteKind.Simple;

        /// <summary>
        /// 走行ルートの出力を指定します。出力しない。
        /// </summary>
        public static readonly PntsOutput PntsOutput = PntsOutput.NotOutput;

        /// <summary>
        /// 経由道路名の出力を指定します。出力しない。
        /// 0：出力しない、1：出力する
        /// </summary>
        public static readonly RnsOutput RnsOutput = RnsOutput.NotOutput;

        /// <summary>
        /// 経由有料道路の出力を指定します。出力しない。
        /// </summary>
        public static readonly TrdsOutput TrdsOutput = TrdsOutput.NotOutput;

        /// <summary>
        /// ジオロケーション構造体の高速道路区間の出力を指定します。出力しない。
        /// </summary>
        public static readonly HighwayOutput HighwayOutput = HighwayOutput.NotOutput;

        /// <summary>
        /// 通行料金の出力を指定します。出力しない。
        /// </summary>
        public static readonly TollOutput TollOutput = TollOutput.NotOutput;

        #endregion

        //=========================================================================================
        //  Public Property
        //=========================================================================================
        #region Public Property

        /// <summary>
        /// 通信プロトコルにSSLを使用するかどうかを指定します。
        /// true：SSLを使用する、false：SSLを使用しない
        /// </summary>
        public static bool UseSsl { get; set; } = false;

        #endregion

        //=========================================================================================
        //  Enum
        //=========================================================================================
        #region Enum

        /// <summary>
        /// ルート計算関数を指定します。
        /// </summary>
        public enum CalcRouteMethod
        {
            /// <summary>
            /// 指定された地点順に計算を行うよう指定します。
            /// </summary>
            CalcRoute,
            /// <summary>
            /// 最適巡回ルート（巡回セールスマン問題）の計算を行うよう指定します。
            /// </summary>
            CalcOptRoute
        }

        #endregion
    }
}
