﻿///////////////////////////////////////////////////////////////////////////////////////////////////
// 
//  ACT距離計算サービス サンプルプログラム
//  ユーティリティクラス
//
//  Copyrights (c) 2011 Advanced Core Technologies, Inc. All rights reserved.
//
//  2011/04/01 Rev.2.2.0.0 ISHI 公開
//
///////////////////////////////////////////////////////////////////////////////////////////////////

using System;

namespace ACTSOAPCSCalcRoute
{
    /// <summary>
    /// ユーティリティクラス
    /// </summary>
    static class Utilities
    {
        /// <summary>
        /// URLのプロトコルをSSLモードによって変更する
        /// </summary>
        /// <param name="url">変更するURL</param>
        /// <param name="sslMode">SSLモード</param>
        /// <returns>変更後のURL</returns>
        public static string ChangeProtocol(string url, bool sslMode)
        {
            Uri uri = new Uri(url);
            string protocol = sslMode ? "https" : "http";
            return string.Format("{0}://{1}{2}", protocol, uri.Host, uri.AbsolutePath);
        }

        /// <summary>
        /// 管理サービス用環境設定オブジェクトから距離計算サービス環境設定オブジェクトを取得する
        /// </summary>
        /// <param name="adminEnviron">管理サービス用環境設定オブジェクト</param>
        /// <returns>距離計算サービス環境設定オブジェクト</returns>
        public static DCService.Environ GetDCServiceEnviron(DCAdmin.Environ adminEnviron)
        {
            DCService.Environ dcEnviron = new DCService.Environ();  //  距離計算サービス環境設定オブジェクト
            dcEnviron.UserID = adminEnviron.UserID;                 //  ユーザID
            dcEnviron.UUID = adminEnviron.UUID;                     //  パスワード
            dcEnviron.Host = adminEnviron.Host;                     //  リスナIPアドレス
            dcEnviron.Port = adminEnviron.Port;                     //  リスナポート番号
            return dcEnviron;
        }

        /// <summary>
        /// 管理サービス用環境設定オブジェクトから住所検索サービス環境設定オブジェクトを取得する
        /// </summary>
        /// <param name="adminEnviron">管理サービス用環境設定オブジェクト</param>
        /// <returns>距離計算サービス環境設定オブジェクト</returns>
        public static GCService.Environ GetGCServiceEnviron(DCAdmin.Environ adminEnviron)
        {
            GCService.Environ gcEnviron = new GCService.Environ();  //  住所検索サービス環境設定オブジェクト
            gcEnviron.UserID = adminEnviron.UserID;                 //  ユーザID
            gcEnviron.UUID = adminEnviron.UUID;                     //  パスワード
            gcEnviron.Host = adminEnviron.Host;                     //  リスナIPアドレス
            gcEnviron.Port = adminEnviron.Port;                     //  リスナポート番号
            return gcEnviron;
        }
    }
}
